@@ -13,6 +13,7 @@ Created by Celia Oakley on 2013-11-05
 """
 
 import unittest
+import re
 import tmdbsimple as tmdb
 
 from tests import API_KEY
@@ -21,17 +22,18 @@ tmdb.API_KEY = API_KEY
 """
 Constants
 """
-CHANGE_KEYS = ['adult', 'air_date', 'also_known_as', 'alternative_titles', \
-    'biography', 'birthday', 'budget', 'cast', 'certifications', \
-    'character_names', 'created_by', 'crew', 'deathday', 'episode', \
-    'episode_number', 'episode_run_time', 'freebase_id', 'freebase_mid', \
-    'general', 'genres', 'guest_stars', 'homepage', 'images', 'imdb_id', \
-    'languages', 'name', 'network', 'origin_country', 'original_name', \
-    'original_title', 'overview', 'parts', 'place_of_birth', 'plot_keywords', \
-    'production_code', 'production_companies', 'production_countries', \
-    'releases', 'revenue', 'runtime', 'season', 'season_number', \
-    'season_regular', 'spoken_languages', 'status', 'tagline', 'title', \
-    'translations', 'tvdb_id', 'tvrage_id', 'type', 'video', 'videos']
+CHANGE_KEYS = ['adult', 'air_date', 'also_known_as', 'alternative_titles',
+               'biography', 'birthday', 'budget', 'cast', 'certifications',
+               'character_names', 'created_by', 'crew', 'deathday', 'episode',
+               'episode_number', 'episode_run_time', 'freebase_id', 'freebase_mid',
+               'general', 'genres', 'guest_stars', 'homepage', 'images', 'imdb_id',
+               'languages', 'name', 'network', 'origin_country', 'original_name',
+               'original_title', 'overview', 'parts', 'place_of_birth', 'plot_keywords',
+               'production_code', 'production_companies', 'production_countries',
+               'releases', 'revenue', 'runtime', 'season', 'season_number',
+               'season_regular', 'spoken_languages', 'status', 'tagline', 'title',
+               'translations', 'tvdb_id', 'tvrage_id', 'type', 'video', 'videos'
+               ]
 ISO_3166_1 = 'iso_3166_1'
 ANDORRA = 'AD'
 ISO_639_1 = 'iso_639_1'
@@ -43,7 +45,7 @@ class ConfigurationTestCase(unittest.TestCase):
     def test_configuration_info(self):
         change_keys = CHANGE_KEYS
         config = tmdb.Configuration()
-        response = config.info()
+        config.info()
         self.assertEqual(config.change_keys, change_keys)
 
         # Also test that bad API_KEY results in exception
@@ -57,19 +59,19 @@ class ConfigurationTestCase(unittest.TestCase):
     def test_configuration_countries(self):
         config = tmdb.Configuration()
         response = config.countries()
-        # First country is Andorra
-        self.assertEqual(response[0][ISO_3166_1], ANDORRA)
+        # Countries are two capital letters
+        self.assertTrue(re.match('^[A-Z]{2}$', response[0][ISO_3166_1]))
 
     def test_configuration_jobs(self):
         config = tmdb.Configuration()
-        response = config.jobs()
+        config.jobs()
         self.assertTrue(hasattr(config, 'jobs'))
 
     def test_configuration_languages(self):
         config = tmdb.Configuration()
         response = config.languages()
-        # First language is No Language
-        self.assertEqual(response[0][ISO_639_1], NO_LANGUAGE)
+        # Languages are two lowercase letters
+        self.assertTrue(re.match('^[a-z]{2}$', response[0][ISO_639_1]))
 
     def test_configuration_primary_translations(self):
         config = tmdb.Configuration()
@@ -87,25 +89,15 @@ class ConfigurationTestCase(unittest.TestCase):
 class CertificationsTestCase(unittest.TestCase):
     def test_certifications_movie_list(self):
         certifications = tmdb.Certifications()
-        response = certifications.movie_list()
+        certifications.movie_list()
         self.assertTrue(hasattr(certifications, 'certifications'))
 
     def test_certifications_tv_list(self):
         certifications = tmdb.Certifications()
-        response = certifications.tv_list()
+        certifications.tv_list()
         self.assertTrue(hasattr(certifications, 'certifications'))
 
     def test_certifications_list(self):
         certifications = tmdb.Certifications()
-        response = certifications.list()
+        certifications.list()
         self.assertTrue(hasattr(certifications, 'certifications'))
-
-
-class TimezonesTestCase(unittest.TestCase):
-    def test_timezones_list(self):
-        timezones = tmdb.Timezones()
-        response = timezones.list()
-        timezone_keys = list(response[0].keys())
-        self.assertEqual(timezone_keys[0], 'AD')
-
-
