@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*- 
+# -*- coding: utf-8 -*-
 """
 test_movies.py
 ~~~~~~~~~~~~~~
@@ -37,7 +37,9 @@ REVIEW_AUTHOR = 'Chris'
 """
 Status Codes
 """
+SUCCESSFUL_CREATE = 1
 SUCCESSFUL_UPDATE = 12
+SUCCESSFUL_DELETE = 13
 
 
 class MoviesTestCase(unittest.TestCase):
@@ -45,136 +47,141 @@ class MoviesTestCase(unittest.TestCase):
         id = MOVIE_ID
         title = MOVIE_TITLE
         movie = tmdb.Movies(id)
-        response = movie.info()
+        movie.info()
         self.assertEqual(movie.title, title)
 
     def test_movies_info_with_params(self):
         id = MOVIE_ID
         title = MOVIE_TITLE_FRENCH
         movie = tmdb.Movies(id)
-        response = movie.info(language='fr')
+        movie.info(language='fr')
         self.assertEqual(movie.title, title)
 
     def test_movies_account_states(self):
         id = MOVIE_ID_ALTERNATIVE
         movie = tmdb.Movies(id)
-        response = movie.account_states(session_id=SESSION_ID)
+        movie.account_states(session_id=SESSION_ID)
         self.assertTrue(hasattr(movie, 'favorite'))
 
     def test_movies_alternative_titles(self):
         id = MOVIE_ID_ALTERNATIVE
         movie = tmdb.Movies(id)
-        response = movie.alternative_titles()
+        movie.alternative_titles()
         self.assertTrue(hasattr(movie, 'titles'))
 
     def test_movies_changes(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.changes()
+        movie.changes()
         self.assertTrue(hasattr(movie, 'changes'))
 
     def test_movies_credits(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.credits()
+        movie.credits()
         self.assertTrue(hasattr(movie, 'cast'))
 
     def test_movies_external_ids(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.external_ids()
+        movie.external_ids()
         self.assertTrue(hasattr(movie, 'imdb_id'))
 
     def test_movies_images(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.images()
+        movie.images()
         self.assertTrue(hasattr(movie, 'backdrops'))
 
     def test_movies_keywords(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.keywords()
+        movie.keywords()
         self.assertTrue(hasattr(movie, 'keywords'))
 
     def test_movies_release_dates(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.release_dates()
+        movie.release_dates()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_videos(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.videos()
+        movie.videos()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_translations(self):
         id = MOVIE_ID_ALTERNATIVE
         movie = tmdb.Movies(id)
-        response = movie.translations()
+        movie.translations()
         self.assertTrue(hasattr(movie, 'translations'))
 
     def test_movies_recommendations(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.recommendations()
+        movie.recommendations()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_similar_movies(self):
         id = MOVIE_ID_ALTERNATIVE
         movie = tmdb.Movies(id)
-        response = movie.similar_movies()
+        movie.similar_movies()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_reviews(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.reviews()
+        movie.reviews()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_lists(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.lists()
+        movie.lists()
         self.assertTrue(hasattr(movie, 'results'))
 
-    def test_movies_rating(self):
+    def test_movies_rating_and_rating_delete(self):
+        status_code_create = SUCCESSFUL_CREATE
+        status_code_update = SUCCESSFUL_UPDATE
+        status_code_delete = SUCCESSFUL_DELETE
         id = MOVIE_ID
-        status_code = SUCCESSFUL_UPDATE
         movie = tmdb.Movies(id)
-        response = movie.rating(session_id=SESSION_ID, value=RATING)
-        self.assertEqual(movie.status_code, status_code)
+        movie.rating(session_id=SESSION_ID, value=RATING)
+        self.assertTrue(movie.status_code == status_code_create
+                        or movie.status_code == status_code_update)
+        movie.rating_delete(session_id=SESSION_ID)
+        self.assertEqual(movie.status_code, status_code_delete)
 
     def test_movies_latest(self):
         movie = tmdb.Movies()
-        response = movie.latest()
+        movie.latest()
         self.assertTrue(hasattr(movie, 'popularity'))
 
     def test_movies_now_playing(self):
         movie = tmdb.Movies()
-        response = movie.now_playing()
+        movie.now_playing()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_popular(self):
         movie = tmdb.Movies()
-        response = movie.popular()
+        movie.popular()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_top_rated(self):
         movie = tmdb.Movies()
-        response = movie.top_rated()
+        movie.top_rated()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_upcoming(self):
         movie = tmdb.Movies()
-        response = movie.upcoming()
+        movie.upcoming()
         self.assertTrue(hasattr(movie, 'results'))
 
     def test_movies_releases(self):
         id = MOVIE_ID
         movie = tmdb.Movies(id)
-        response = movie.releases()
+        movie.releases()
         self.assertTrue(hasattr(movie, 'countries'))
 
 
@@ -183,19 +190,19 @@ class CollectionsTestCase(unittest.TestCase):
         id = COLLECTION_ID
         name = COLLECTION_NAME
         collection = tmdb.Collections(id)
-        response = collection.info()
+        collection.info()
         self.assertEqual(collection.name, name)
 
     def test_collections_images(self):
         id = COLLECTION_ID
         collection = tmdb.Collections(id)
-        response = collection.images()
+        collection.images()
         self.assertTrue(hasattr(collection, 'backdrops'))
 
     def test_collections_translations(self):
         id = COLLECTION_ID
         collection = tmdb.Collections(id)
-        response = collection.translations()
+        collection.translations()
         self.assertTrue(hasattr(collection, 'translations'))
 
 
@@ -204,25 +211,25 @@ class CompaniesTestCase(unittest.TestCase):
         id = COMPANY_ID
         name = COMPANY_NAME
         company = tmdb.Companies(id)
-        response = company.info()
+        company.info()
         self.assertEqual(company.name, name)
 
     def test_companies_alternative_names(self):
         id = COMPANY_ID
         company = tmdb.Companies(id)
-        response = company.alternative_names()
+        company.alternative_names()
         self.assertTrue(hasattr(company, 'results'))
 
     def test_companies_images(self):
         id = COMPANY_ID
         company = tmdb.Companies(id)
-        response = company.images()
+        company.images()
         self.assertTrue(hasattr(company, 'logos'))
 
     def test_companies_movies(self):
         id = COMPANY_ID
         company = tmdb.Companies(id)
-        response = company.movies()
+        company.movies()
         self.assertTrue(hasattr(company, 'results'))
 
 
@@ -231,13 +238,13 @@ class KeywordsTestCase(unittest.TestCase):
         id = KEYWORD_ID
         name = KEYWORD_NAME
         keyword = tmdb.Keywords(id)
-        response = keyword.info()
+        keyword.info()
         self.assertEqual(keyword.name, name)
 
     def test_keywords_movies(self):
         id = KEYWORD_ID
         keyword = tmdb.Keywords(id)
-        response = keyword.movies()
+        keyword.movies()
         self.assertTrue(hasattr(keyword, 'results'))
 
 
@@ -246,6 +253,5 @@ class ReviewsTestCase(unittest.TestCase):
         id = REVIEW_ID
         author = REVIEW_AUTHOR
         review = tmdb.Reviews(id)
-        response = review.info()
+        review.info()
         self.assertEqual(review.author, author)
-
