@@ -3,7 +3,7 @@
 """
 tmdbsimple.account
 ~~~~~~~~~~~~~~~~~~
-This module implements the Account, Authentication, and Lists functionality 
+This module implements the Account, Authentication, and Lists functionality
 of tmdbsimple.
 
 Created by Celia Oakley on 2013-10-31.
@@ -25,7 +25,7 @@ class Account(TMDB):
     BASE_PATH = 'account'
     URLS = {
         'info': '',
-        'lists': '/{id}/lists', 
+        'lists': '/{id}/lists',
         'favorite_movies': '/{id}/favorite/movies',
         'favorite_tv': '/{id}/favorite/tv',
         'favorite': '/{id}/favorite',
@@ -45,7 +45,7 @@ class Account(TMDB):
         """
         Get your account details.
 
-        Call this method first, before calling other Account methods.
+        Args:
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -57,14 +57,15 @@ class Account(TMDB):
         self.id = response['id']
         self._set_attrs_to_values(response)
         return response
-        
+
     def lists(self, **kwargs):
         """
-        Get all of the lists created by an account. Will include private lists if you are the owner.
+        Get all of the lists created by an account. Will include private lists
+        if you are the owner.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -81,9 +82,9 @@ class Account(TMDB):
         Get the list of your favorite movies.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
             language: (optional) ISO 639-1 code.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -100,9 +101,9 @@ class Account(TMDB):
         Get the list of your favorite TV shows.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
             language: (optional) ISO 639-1 code.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -130,8 +131,8 @@ class Account(TMDB):
         kwargs.update({'session_id': self.session_id})
 
         payload = {
-            'media_type': kwargs.pop('media_type', None), 
-            'media_id': kwargs.pop('media_id', None), 
+            'media_type': kwargs.pop('media_type', None),
+            'media_id': kwargs.pop('media_id', None),
             'favorite': kwargs.pop('favorite', None),
         }
 
@@ -144,9 +145,9 @@ class Account(TMDB):
         Get a list of all the movies you have rated.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            language: (optional) ISO 639-1 value.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -163,9 +164,9 @@ class Account(TMDB):
         Get a list of all the TV shows you have rated.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            language: (optional) ISO 639-1 value.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -182,9 +183,9 @@ class Account(TMDB):
         Get a list of all the TV episodes you have rated.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            language: (optional) ISO 639-1 value.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -201,9 +202,9 @@ class Account(TMDB):
         Get a list of all the movies you have added to your watchlist.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            language: (optional) ISO 639-1 value.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -220,9 +221,9 @@ class Account(TMDB):
         Get a list of all the TV shows you have added to your watchlist.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            language: (optional) ISO 639-1 value.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -250,8 +251,8 @@ class Account(TMDB):
         kwargs.update({'session_id': self.session_id})
 
         payload = {
-            'media_type': kwargs.pop('media_type', None), 
-            'media_id': kwargs.pop('media_id', None), 
+            'media_type': kwargs.pop('media_type', None),
+            'media_id': kwargs.pop('media_id', None),
             'watchlist': kwargs.pop('watchlist', None),
         }
 
@@ -259,6 +260,7 @@ class Account(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+
 class Authentication(TMDB):
     """
     Authentication functionality.
@@ -268,10 +270,11 @@ class Authentication(TMDB):
     """
     BASE_PATH = 'authentication'
     URLS = {
-        'guest_session_new': '/guest_session/new', 
+        'guest_session_new': '/guest_session/new',
         'token_new': '/token/new',
-        'session_new': '/session/new', 
+        'session_new': '/session/new',
         'token_validate_with_login': '/token/validate_with_login',
+        'session_delete': '/session',
     }
 
     def guest_session_new(self, **kwargs):
@@ -291,6 +294,8 @@ class Authentication(TMDB):
         If a guest session is not used for the first time within 24 hours,
         it will be automatically deleted.
 
+        Args:
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -306,6 +311,8 @@ class Authentication(TMDB):
         user login. More details about how this works can be found here
         (https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id).
 
+        Args:
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -365,6 +372,26 @@ class Authentication(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def session_delete(self, **kwargs):
+        """
+        If you would like to delete (or "logout") from a session, call this
+        method with a valid session ID.
+
+        Args:
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_path('session_delete')
+
+        payload = {
+            'session_id': kwargs.pop('session_id', None),
+        }
+
+        response = self._DELETE(path, kwargs, payload)
+        self._set_attrs_to_values(response)
+        return response
+
 
 class GuestSessions(TMDB):
     """
@@ -388,9 +415,8 @@ class GuestSessions(TMDB):
         Get the rated movies for a guest session.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
             language: (optional) ISO 639-1 code.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -400,15 +426,14 @@ class GuestSessions(TMDB):
         response = self._GET(path, kwargs)
         self._set_attrs_to_values(response)
         return response
- 
+
     def rated_tv(self, **kwargs):
         """
         Get the rated TV shows for a guest session.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
             language: (optional) ISO 639-1 code.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -418,15 +443,14 @@ class GuestSessions(TMDB):
         response = self._GET(path, kwargs)
         self._set_attrs_to_values(response)
         return response
- 
+
     def rated_tv_episodes(self, **kwargs):
         """
         Get the rated TV episodes for a guest session.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
             language: (optional) ISO 639-1 code.
+            sort_by: (optional) Allowed Values: created_at.asc, created_at.desc
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -436,7 +460,7 @@ class GuestSessions(TMDB):
         response = self._GET(path, kwargs)
         self._set_attrs_to_values(response)
         return response
- 
+
 
 class Lists(TMDB):
     """
@@ -447,11 +471,12 @@ class Lists(TMDB):
     BASE_PATH = 'list'
     URLS = {
         'info': '/{id}',
-        'item_status': '/{id}/item_status', 
-        'create_list': '',
+        'item_status': '/{id}/item_status',
+        'list_create': '',
         'add_item': '/{id}/add_item',
         'remove_item': '/{id}/remove_item',
-        'clear': '/{id}/clear',
+        'list_clear': '/{id}/clear',
+        'list_delete': '/{id}',
     }
 
     def __init__(self, id=0, session_id=0):
@@ -463,6 +488,9 @@ class Lists(TMDB):
         """
         Get the details of a list.
 
+        Args:
+            language: (optional) ISO 639-1 code.
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -478,7 +506,7 @@ class Lists(TMDB):
         the list.
 
         Args:
-            movie_id: The id of the movie.
+            movie_id: The id of the movie.  Minimum 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -489,7 +517,7 @@ class Lists(TMDB):
         self._set_attrs_to_values(response)
         return response
 
-    def create_list(self, **kwargs):
+    def list_create(self, **kwargs):
         """
         Create a list.
 
@@ -501,18 +529,18 @@ class Lists(TMDB):
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
-        path = self._get_path('create_list')
+        path = self._get_path('list_create')
         kwargs.update({'session_id': self.session_id})
 
         payload = {
-            'name': kwargs.pop('name', None), 
+            'name': kwargs.pop('name', None),
             'description': kwargs.pop('description', None),
+            'language': kwargs.pop('language', None),
         }
-        if 'language' in kwargs:
-            payload['language'] = kwargs['language']
 
         response = self._POST(path, kwargs, payload)
         self._set_attrs_to_values(response)
+        self.id = self.list_id
         return response
 
     def add_item(self, **kwargs):
@@ -520,7 +548,7 @@ class Lists(TMDB):
         Add a movie to a list.
 
         Args:
-            media_id: A movie id.
+            media_id: A movie id.  Minimum 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -529,19 +557,19 @@ class Lists(TMDB):
         kwargs.update({'session_id': self.session_id})
 
         payload = {
-            'media_id': kwargs.pop('media_id', None), 
+            'media_id': kwargs.pop('media_id', None),
         }
 
         response = self._POST(path, kwargs, payload)
         self._set_attrs_to_values(response)
         return response
-        
+
     def remove_item(self, **kwargs):
         """
         Remove a movie from a list.
 
         Args:
-            media_id: A movie id.
+            media_id: A movie id.  Minimum 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -550,14 +578,14 @@ class Lists(TMDB):
         kwargs.update({'session_id': self.session_id})
 
         payload = {
-            'media_id': kwargs.pop('media_id', None), 
+            'media_id': kwargs.pop('media_id', None),
         }
 
         response = self._POST(path, kwargs, payload)
         self._set_attrs_to_values(response)
         return response
 
-    def clear_list(self, **kwargs):
+    def list_clear(self, **kwargs):
         """
         Clear all of the items from a list.
 
@@ -567,7 +595,7 @@ class Lists(TMDB):
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
-        path = self._get_id_path('clear')
+        path = self._get_id_path('list_clear')
         kwargs.update({'session_id': self.session_id})
 
         payload = {}
@@ -575,3 +603,20 @@ class Lists(TMDB):
         response = self._POST(path, kwargs, payload)
         self._set_attrs_to_values(response)
         return response
+
+    def list_delete(self, **kwargs):
+        """
+        Delete a list.
+
+        Args:
+            None
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_id_path('list_delete')
+        kwargs.update({'session_id': self.session_id})
+
+        response = self._DELETE(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
