@@ -14,6 +14,7 @@ Created by Celia Oakley on 2013-10-31.
 
 from .base import TMDB
 
+
 class Movies(TMDB):
     """
     Movies functionality.
@@ -37,13 +38,14 @@ class Movies(TMDB):
         'similar_movies': '/{id}/similar_movies',
         'reviews': '/{id}/reviews',
         'lists': '/{id}/lists',
+        'rating': '/{id}/rating',
+        'rating_delete': '/{id}/rating',
         'latest': '/latest',
         'now_playing': '/now_playing',
         'popular': '/popular',
         'top_rated': '/top_rated',
         'upcoming': '/upcoming',
-        'rating': '/{id}/rating',     # backward compatability
-        'releases': '/{id}/releases', # backward compatability
+        'releases': '/{id}/releases',   # backward compatability
     }
 
     def __init__(self, id=0):
@@ -59,7 +61,8 @@ class Movies(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
+            append_to_response: (optional) Append requests within the same
+                namespace to the response.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -78,7 +81,8 @@ class Movies(TMDB):
             - If it belongs to your favourite list
 
         Args:
-            session_id: see Authentication.
+            session_id: (required) See Authentication.
+            guest_session_id: (optional) See Authentication.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -95,7 +99,6 @@ class Movies(TMDB):
 
         Args:
             country: (optional) ISO 3166-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -114,8 +117,11 @@ class Movies(TMDB):
         and end_date query parameters.
 
         Args:
-            start_date: (optional) Expected format is 'YYYY-MM-DD'.
-            end_date: (optional) Expected format is 'YYYY-MM-DD'.
+            start_date: (optional) Filter the results with a start date.
+                Expected format is 'YYYY-MM-DD'.
+            end_date: (optional) Filter the results with a end date.
+                Expected format is 'YYYY-MM-DD'.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -131,7 +137,7 @@ class Movies(TMDB):
         Get the cast and crew for a movie.
 
         Args:
-            append_to_response: (optional) Comma separated, any movie method.
+            None
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -151,8 +157,7 @@ class Movies(TMDB):
         Social IDs - Facebok, Instagram, Twitter
 
         Args:
-            language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
+            None
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -175,7 +180,6 @@ class Movies(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
             include_image_language: (optional) Comma separated, a valid
                                     ISO 69-1.
 
@@ -192,6 +196,9 @@ class Movies(TMDB):
         """
         Get the keywords that have been added to a movie.
 
+        Args:
+            None
+
         Returns:
             A dict representation of the JSON returned from the API.
         """
@@ -215,7 +222,7 @@ class Movies(TMDB):
             6. TV
 
         Args:
-            append_to_response: (optional) Comma separated, any movie method.
+            None
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -231,7 +238,7 @@ class Movies(TMDB):
         Get the videos that have been added to a movie.
 
         Args:
-            append_to_response: (optional) Comma separated, any movie method.
+            language: (optional) ISO 639-1 code.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -247,7 +254,7 @@ class Movies(TMDB):
         Get a list of translations that have been created for a movie.
 
         Args:
-            append_to_response: (optional) Comma separated, any movie method.
+            None
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -264,7 +271,7 @@ class Movies(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            page: (optional) Minimum value of 1.  Expected value is an integer.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -283,9 +290,8 @@ class Movies(TMDB):
         These items are assembled by looking at keywords and genres.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -301,9 +307,8 @@ class Movies(TMDB):
         Get the user reviews for a movie.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -319,9 +324,8 @@ class Movies(TMDB):
         Get a list of lists that this movie belongs to.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -341,9 +345,10 @@ class Movies(TMDB):
         https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id.
 
         Args:
-            session_id: see Authentication.
-            guest_session_id: see Authentication.
-            value: Rating value.
+            session_id: (optional) See Authentication.
+            guest_session_id: (optional) See Authentication.
+            value: (required) This is the value of the rating you want to
+                submit. The value is expected to be between 0.5 and 10.0.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -358,11 +363,39 @@ class Movies(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def rating_delete(self, **kwargs):
+        """
+        Remove your rating for a movie.
+
+        A valid session or guest session ID is required. You can read more
+        about how this works at
+        https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id.
+
+        Args:
+            session_id: (optional) See Authentication.
+            guest_session_id: (optional) See Authentication.
+
+        Returns:
+            A dict representation of the JSON returned from the API.
+        """
+        path = self._get_id_path('rating_delete')
+
+        payload = {
+            'value': kwargs.pop('value', None),
+        }
+
+        response = self._DELETE(path, kwargs, payload)
+        self._set_attrs_to_values(response)
+        return response
+
     def latest(self, **kwargs):
         """
         Get the most newly created movie. This is a live response and will
         continuously change.
 
+        Args:
+            language: (optional) ISO 639-1 code.
+
         Returns:
             A dict representation of the JSON returned from the API.
         """
@@ -383,8 +416,10 @@ class Movies(TMDB):
         country.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
+            region: (optional) Specify a ISO 3166-1 code to filter release
+                dates. Must be uppercase.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -401,8 +436,10 @@ class Movies(TMDB):
         daily.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
+            region: (optional) Specify a ISO 3166-1 code to filter release
+                dates. Must be uppercase.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -418,8 +455,10 @@ class Movies(TMDB):
         Get the top rated movies on TMDb.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
+            region: (optional) Specify a ISO 3166-1 code to filter release
+                dates. Must be uppercase.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -441,8 +480,10 @@ class Movies(TMDB):
         country.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
+            region: (optional) Specify a ISO 3166-1 code to filter release
+                dates. Must be uppercase.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -460,7 +501,7 @@ class Movies(TMDB):
         specific movie id.
 
         Args:
-            append_to_response: (optional) Comma separated, any movie method.
+            None
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -495,7 +536,6 @@ class Collections(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -512,9 +552,6 @@ class Collections(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
-            include_image_language: (optional) Comma separated, a valid
-            ISO 69-1.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -531,7 +568,6 @@ class Collections(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -542,6 +578,7 @@ class Collections(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+
 class Companies(TMDB):
     """
     Companies functionality.
@@ -553,7 +590,7 @@ class Companies(TMDB):
         'info': '/{id}',
         'alternative_names': '/{id}/alternative_names',
         'images': '/{id}/images',
-        'movies': '/{id}/movies', # backward compatability
+        'movies': '/{id}/movies',    # backward compatability
     }
 
     def __init__(self, id=0):
@@ -565,7 +602,6 @@ class Companies(TMDB):
         Get a companies details by id.
 
         Args:
-            append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -622,9 +658,8 @@ class Companies(TMDB):
         Get the list of movies associated with a particular company.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
+            page: (optional) Minimum value of 1.  Expected value is an integer.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -656,6 +691,9 @@ class Keywords(TMDB):
         """
         Get the details of a keyword.
 
+        Args:
+           None
+
         Returns:
             A dict representation of the JSON returned from the API.
         """
@@ -673,8 +711,9 @@ class Keywords(TMDB):
         is much more flexible.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
+            include_adult: Choose whether to inlcude adult (pornography)
+                content in the results.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -685,6 +724,7 @@ class Keywords(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+
 class Reviews(TMDB):
     """
     Reviews functionality.
@@ -704,6 +744,9 @@ class Reviews(TMDB):
         """
         Get the review details by id.
 
+        Args:
+            None
+
         Returns:
             A dict representation of the JSON returned from the API.
         """
