@@ -14,6 +14,7 @@ Created by Celia Oakley on 2013-10-31.
 
 from .base import TMDB
 
+
 class TV(TMDB):
     """
     TV functionality.
@@ -58,8 +59,8 @@ class TV(TMDB):
 
         Args:
             language: (optional) ISO 639 code.
-            append_to_response: (optional) Comma separated, any TV series
-                                method.
+            append_to_response: (optional) Append requests within the same
+                namespace to the response.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -79,7 +80,9 @@ class TV(TMDB):
 
         Args:
             language: (optional) ISO 3166-1 code.
-            append_to_response: (optional) Comma separated, any tv method.
+            session_id: (required) See Authentication.
+            guest_session_id: (optional) See Authentication.
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -95,7 +98,7 @@ class TV(TMDB):
 
         Args:
             language: (optional) ISO 3166-1 code.
-            append_to_response: (optional) Comma separated, any tv method.
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -111,9 +114,7 @@ class TV(TMDB):
         to a TV show.
 
         Args:
-            language: (optional) ISO 639 code.
-            append_to_response: (optional) Comma separated, any collection
-                                method.
+            language: (optional) ISO 3166-1 code.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -130,8 +131,6 @@ class TV(TMDB):
 
         Args:
             language: (optional) ISO 639 code.
-            append_to_response: (optional) Comma separated, any collection
-                                method.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -194,8 +193,6 @@ class TV(TMDB):
 
         Args:
             language: (optional) ISO 639 code.
-            include_image_language: (optional) Comma separated, a valid
-                                    ISO 69-1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -210,6 +207,9 @@ class TV(TMDB):
         """
         Get the keywords that have been added to a TV show.
 
+        Args:
+            None
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -224,8 +224,8 @@ class TV(TMDB):
         Get the list of TV show recommendations for this item.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -241,8 +241,8 @@ class TV(TMDB):
         Get the reviews for a TV show.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -259,8 +259,7 @@ class TV(TMDB):
         festival or theatre.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
-            language: (optional) ISO 639-1 code.
+            None
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -277,9 +276,8 @@ class TV(TMDB):
         keywords and genres.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any TV method.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -294,6 +292,9 @@ class TV(TMDB):
         """
         Get a list of the translations that exist for a TV show.
 
+        Args:
+            None
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -328,9 +329,10 @@ class TV(TMDB):
         https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id.
 
         Args:
-            session_id: see Authentication.
-            guest_session_id: see Authentication.
-            value: Rating value.
+            session_id: (optional) See Authentication.
+            guest_session_id: (optional) See Authentication.
+            value: (required) This is the value of the rating you want to
+                submit. The value is expected to be between 0.5 and 10.0.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -345,6 +347,31 @@ class TV(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def rating_delete(self, **kwargs):
+        """
+        Remove your rating for a TV show.
+
+        A valid session or guest session ID is required. You can read more
+        about how this works at
+        https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id.
+
+        Args:
+            session_id: (optional) See Authentication.
+            guest_session_id: (optional) See Authentication.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_id_path('rating')
+
+        payload = {
+            'value': kwargs.pop('value', None),
+        }
+
+        response = self._DELETE(path, kwargs, payload)
+        self._set_attrs_to_values(response)
+        return response
+
     def latest(self, **kwargs):
         """
         Get the most newly created TV show. This is a live response and will
@@ -372,9 +399,8 @@ class TV(TMDB):
         UTC-05:00).
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639 code.
-            timezone: (optional) Valid value from the list of timezones.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -393,8 +419,8 @@ class TV(TMDB):
         in the next 7 days.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -411,8 +437,8 @@ class TV(TMDB):
         daily.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -428,8 +454,8 @@ class TV(TMDB):
         Get a list of the top rated TV shows on TMDb.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -471,8 +497,8 @@ class TV_Seasons(TMDB):
 
         Args:
             language: (optional) ISO 639 code.
-            append_to_response: (optional) Comma separated, any TV series
-                                method.
+            append_to_response: (optional) Append requests within the same
+                namespace to the response.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -489,8 +515,8 @@ class TV_Seasons(TMDB):
 
         Args:
             language: (optional) ISO 639 code.
-            append_to_response: (optional) Comma separated, any TV series
-                                method.
+            session_id: (required) See Authentication.
+            guest_session_id: (optional) See Authentication.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -505,6 +531,9 @@ class TV_Seasons(TMDB):
         """
         Get the credits for TV season.
 
+        Args:
+            language: (optional) ISO 639 code.
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -547,8 +576,6 @@ class TV_Seasons(TMDB):
 
         Args:
             language: (optional) ISO 639 code.
-            include_image_language: (optional) Comma separated, a valid
-                                    ISO 69-1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -609,8 +636,8 @@ class TV_Episodes(TMDB):
 
         Args:
             language: (optional) ISO 639 code.
-            append_to_response: (optional) Comma separated, any TV series
-                                method.
+            append_to_response: (optional) Append requests within the same
+                namespace to the response.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -626,9 +653,8 @@ class TV_Episodes(TMDB):
         Get your rating for an episode.
 
         Args:
-            language: (optional) ISO 639 code.
-            append_to_response: (optional) Comma separated, any TV series
-                                method.
+            session_id: (required) See Authentication.
+            guest_session_id: (optional) See Authentication.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -643,6 +669,9 @@ class TV_Episodes(TMDB):
         """
         Get the credits (cast, crew and guest stars) for a TV episode.
 
+        Args:
+            None
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -659,11 +688,11 @@ class TV_Episodes(TMDB):
 
         External Sources: IMDb ID, TVDB ID, Freebase MID*, Freebase ID*, TVRage
         ID*
-        
+
         *Defunct or no longer available as a service.
 
         Args:
-            language: (optional) ISO 639 code.
+            None
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -685,6 +714,9 @@ class TV_Episodes(TMDB):
         should be a comma seperated value like so:
         include_image_language=en,null.
 
+        Args:
+            None
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -698,6 +730,9 @@ class TV_Episodes(TMDB):
         """
         Get the translation data for an episode.
 
+        Args:
+            None
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -716,9 +751,10 @@ class TV_Episodes(TMDB):
         https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id.
 
         Args:
-            session_id: see Authentication.
-            guest_session_id: see Authentication.
-            value: Rating value.
+            session_id: (optional) See Authentication.
+            guest_session_id: (optional) See Authentication.
+            value: (required) This is the value of the rating you want to
+                submit. The value is expected to be between 0.5 and 10.0.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -733,6 +769,31 @@ class TV_Episodes(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def rating_delete(self, **kwargs):
+        """
+        Remove your rating for a TV episode.
+
+        A valid session or guest session ID is required. You can read more
+        about how this works at
+        https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id.
+
+        Args:
+            session_id: (optional) See Authentication.
+            guest_session_id: (optional) See Authentication.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_tv_id_season_number_episode_number_path('rating')
+
+        payload = {
+            'value': kwargs.pop('value', None),
+        }
+
+        response = self._DELETE(path, kwargs, payload)
+        self._set_attrs_to_values(response)
+        return response
+
     def videos(self, **kwargs):
         """
         Get the videos that have been added to a TV episode.
@@ -775,7 +836,7 @@ class TV_Episode_Groups(TMDB):
             4. Digital
             5. Story arc
             6. Production
-            7. TV        
+            7. TV
 
         Args:
             language: (optional) ISO 639 code.
@@ -823,9 +884,11 @@ class TV_Changes(TMDB):
         changes and episode changes methods to look these up individually.
 
         Args:
-            start_date: (optional) Expected format is 'YYYY-MM-DD'.
-            end_date: (optional) Expected format is 'YYYY-MM-DD'.
-            page: (optional) Minimum 1, maximum 1000.
+            start_date: (optional) Filter the results with a start date.
+                Expected format is 'YYYY-MM-DD'.
+            end_date: (optional) Filter the results with a end date.
+                Expected format is 'YYYY-MM-DD'.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -844,9 +907,11 @@ class TV_Changes(TMDB):
         and end_date query parameters.
 
         Args:
-            start_date: (optional) Expected format is 'YYYY-MM-DD'.
-            end_date: (optional) Expected format is 'YYYY-MM-DD'.
-            page: (optional) Minimum 1, maximum 1000.
+            start_date: (optional) Filter the results with a start date.
+                Expected format is 'YYYY-MM-DD'.
+            end_date: (optional) Filter the results with a end date.
+                Expected format is 'YYYY-MM-DD'.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -865,9 +930,11 @@ class TV_Changes(TMDB):
         and end_date query parameters.
 
         Args:
-            start_date: (optional) Expected format is 'YYYY-MM-DD'.
-            end_date: (optional) Expected format is 'YYYY-MM-DD'.
-            page: (optional) Minimum 1, maximum 1000.
+            start_date: (optional) Filter the results with a start date.
+                Expected format is 'YYYY-MM-DD'.
+            end_date: (optional) Filter the results with a end date.
+                Expected format is 'YYYY-MM-DD'.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -900,6 +967,9 @@ class Networks(TMDB):
         """
         Get the details of a network.
 
+        Args:
+            None
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -914,6 +984,7 @@ class Networks(TMDB):
         Get the alternative names of a network.
 
         Args:
+            None
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -939,6 +1010,7 @@ class Networks(TMDB):
         through https://developers.themoviedb.org/3/getting-started/images.
 
         Args:
+            None
 
         Returns:
             A dict representation of the JSON returned from the API.
